@@ -16,6 +16,9 @@ def main():
         tags = sys.argv[3:]
         for tag in tags:
             t.tag_file(file_name, tag)
+    elif sys.argv[1] == "rmtag":
+        tag = sys.argv[2]
+        t.delete_tag(tag)
     elif sys.argv[1] == "rm":
         file_name = os.path.abspath(sys.argv[2])
         t.rm_file(file_name)
